#
# Figure 5 for Diversity Paper with Epstein and Knight
#

#
# Set Parameters
#
start <- 1789
end <- 2001

#
# Load Data
#
library(foreign)
sdd<- read.spss("sdd2.sav", to.data.frame=TRUE)
attach(sdd)

#
# Variables
#
# YEAR NJUSTICE PROPEX PROPSTEX 
# PROPFEEX  PROELECT  PROELLEG PROELEXE
# PROLEGEX  PROSTLEG   PROFLEG  PROEXEXP
# PROAG    PROCAB  MEANYEAR PROPRIVA 
# PROPGOVT  PROPEXEC   PROPEXE   PRSTLEG
# PROFELEG  PROSTJUD PROFEJUD  PROPROFS
# PRIVATE1   GOVLEG1  GOVNONE1  PRIVATE2
# GOVATTY2  EXECBR2 LEGIS2 JUDGE2 
# PROPRIV3 ALLOTH3 MEANSTJ MEANFEDJ
# MEANJEXP ELECTED ATTORNEY POLEXP 
# LEGEXP ACAEXP MEANACA JEXPPRO
# FJEXP STJEXP MLEXP 

pdf("fig2.pdf", paper="letter", width=6.5, height=8.5, horizontal=FALSE)
par(mfrow=c(3,1), mai=c(.7,.6,.3,.1), lab=c(9, 5, 7))

plot(YEAR, 100*JUDGE1, type="l", ylab="Percentage [%]", 
main="A. Justices Serving as State or Federal Judges When Appointed", 
ylim=c(0,100), xlab="Year")
abline(v=1869)

plot(YEAR, 100*FEDJUDGE, type="l", ylab="Percentage [%]",
main="B. Justices Serving as Federal Court Judges When Appointed", ylim=c(0,100), xlab="Year")
abline(v=1869)

plot(YEAR, 100*STJUDGE, type="l", ylab="Percentage [%]",
main="C. Justices Serving as State Court Judges When Appointed", ylim=c(0,100), xlab="Year")
abline(v=1869)

# Hypotheses
regx <- start:end
regx2 <- start:1950
regx3 <- 1951:2000

JUDGE2 <- JUDGE1[1:162]
JUDGE3 <- JUDGE1[163:212]

summary(lm(FEDJUDGE~regx))
summary(lm(STJUDGE~regx))
summary(lm(JUDGE2~regx2))
summary(lm(JUDGE3~regx3))
t.test(JUDGE2,JUDGE3)
dev.off()



