#
# Figure 3 for Diversity Paper with Epstein and Knight
#

#
# Set Parameters
#
start <- 1789
end <- 2001

#
# Load Data
#
library(foreign)
sdd<- read.spss("sdd2.sav", to.data.frame=TRUE)
attach(sdd)

#
# Variables
#
# YEAR NJUSTICE PROPEX PROPSTEX 
# PROPFEEX  PROELECT  PROELLEG PROELEXE
# PROLEGEX  PROSTLEG   PROFLEG  PROEXEXP
# PROAG    PROCAB  MEANYEAR PROPRIVA 
# PROPGOVT  PROPEXEC   PROPEXE   PRSTLEG
# PROFELEG  PROSTJUD PROFEJUD  PROPROFS
# PRIVATE1   GOVLEG1  GOVNONE1  PRIVATE2
# GOVATTY2  EXECBR2 LEGIS2 JUDGE2 
# PROPRIV3 ALLOTH3 MEANSTJ MEANFEDJ
# MEANJEXP ELECTED ATTORNEY POLEXP 
# LEGEXP ACAEXP MEANACA JEXPPRO
# FJEXP STJEXP MLEXP 

pdf("fig4.pdf", paper="letter", width=6.5, height=8.5, horizontal=FALSE)
par(mfrow=c(3,1), mai=c(.7,.7,.3,.1), lab=c(9, 5, 7), cex=.7)

plot(YEAR, 100*LEGIS1, type="l", ylab="Percentage [%]", xlab="Year",
main="A. Justices Serving as Legislators When Appointed", ylim=c(0,100))

plot(YEAR, 100*ELECTEXE, type="l", ylab="Percentage [%]", main=
"B. Justices Serving as Elected Officials in the Executive Branch When Appointed", xlab="Year", ylim=c(0,100))

plot(YEAR, 100*NOELECTE, type="l", ylab="Percentage [%]", main="C. Justices Serving as Appointed Officials in the Executive Branch When Appointed", xlab="Year", ylim=c(0,100))



# Hypothesis Testing
regx <- start:end
summary(lm(EXEC1~regx))
summary(lm(ELECT~regx))
summary(lm(POLEXP~regx))

dev.off()




